@@ -10,3 +10,7 @@ Solid::Ifaces::Block::~Block()
 {
 }
 
+bool Solid::Ifaces::Block::isSystem() const
+{
+    return false;
+}
